**To remove a virtual MFA device**

The following ``delete-virtual-mfa-device`` command removes the specified MFA device from the current account::

  aws iam delete-virtual-mfa-device --serial-number arn:aws:iam::123456789012:mfa/MFATest

For more information, see `Using a Virtual MFA Device with AWS`_ in the *Using IAM* guide.

.. _`Using a Virtual MFA Device with AWS`: http://docs.aws.amazon.com/IAM/latest/UserGuide/Using_VirtualMFA.html

